.. _getting-started:

Getting Started
###############


.. grid:: 1
   :gutter: 3

   .. grid-item-card:: Desktop Installation
      :link-type: doc
      :link: desktop_installation

      Instructions for installing the solution on desktop.

.. grid:: 1
   :gutter: 3

   .. grid-item-card:: Docker Installation
      :link-type: doc
      :link: docker_installation

      Instructions for installing the solution on Docker container.


.. toctree::
   :hidden:
   :maxdepth: 3

   desktop_installation
   docker_installation
